summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRahul P2022-02-28 17:11:06 +0530
committerGitHub2022-02-28 17:11:06 +0530
commit38f357d067edfc11c4d6268106b02688833baa7b (patch)
tree88f8dd83feab3fb5348fed85b31b2530678c0af6
parentd7ba0a2d47e0a76a24d1c9d86837ec6505883b72 (diff)
parent9686d45404cd272310173f8ef0ce61380c3d0b40 (diff)
downloadeSim-38f357d067edfc11c4d6268106b02688833baa7b.tar.gz
eSim-38f357d067edfc11c4d6268106b02688833baa7b.tar.bz2
eSim-38f357d067edfc11c4d6268106b02688833baa7b.zip
Merge pull request #200 from rahulp13/master
Refactor UI element names
-rw-r--r--README.md2
-rw-r--r--src/frontEnd/Application.py2
-rwxr-xr-xsrc/maker/Maker.py4
-rwxr-xr-xsrc/maker/NgVeri.py18
4 files changed, 13 insertions, 13 deletions
diff --git a/README.md b/README.md
index de871b36..aea9fa8b 100644
--- a/README.md
+++ b/README.md
@@ -16,7 +16,7 @@ It is an integrated tool build using open source softwares such as KiCad, Ngspic
## Releases and Installation
eSim is released for the following distributions (operating systems):
* Ubuntu 18.04 and 20.04 LTS versions.
-* Microsoft Windows 7, 8 and 10.
+* Microsoft Windows 8 and 10.
To use eSim on your machine having above distributions, please refer to link [here](https://esim.fossee.in/downloads) for installation and other guidelines.
diff --git a/src/frontEnd/Application.py b/src/frontEnd/Application.py
index 24955c60..d3ef020f 100644
--- a/src/frontEnd/Application.py
+++ b/src/frontEnd/Application.py
@@ -193,7 +193,7 @@ class Application(QtWidgets.QMainWindow):
self.ngspice = QtWidgets.QAction(
QtGui.QIcon(init_path + 'images/ngspice.png'),
- '<b>Simulation</b>', self
+ '<b>Simulate</b>', self
)
self.ngspice.triggered.connect(self.open_ngspice)
diff --git a/src/maker/Maker.py b/src/maker/Maker.py
index c7a66204..e5d11988 100755
--- a/src/maker/Maker.py
+++ b/src/maker/Maker.py
@@ -357,7 +357,7 @@ Please check if verilog file is chosen.")
# self.optionsbox2.setTitle("Note: Please save the file once edited")
# self.optionsgrid2 = QtWidgets.QGridLayout()
self.optionsgroupbtn = QtWidgets.QButtonGroup()
- self.addoptions = QtWidgets.QPushButton("Add Top Level Verilog file")
+ self.addoptions = QtWidgets.QPushButton("Add Top Level Verilog Model")
self.optionsgroupbtn.addButton(self.addoptions)
self.addoptions.clicked.connect(self.addverilog)
self.optionsgrid.addWidget(self.addoptions, 0, 1)
@@ -375,7 +375,7 @@ Please check if verilog file is chosen.")
self.optionsgrid.addWidget(self.saveoption, 0, 3)
# self.optionsbox.setLayout(self.optionsgrid)
# self.grid.addWidget(self.creategroup(), 1, 0, 5, 0)
- self.runoptions = QtWidgets.QPushButton("Edit in Makerchip")
+ self.runoptions = QtWidgets.QPushButton("Edit in Makerchip IDE")
self.runoptions.setToolTip(
"Requires internet connection and a browser"
)
diff --git a/src/maker/NgVeri.py b/src/maker/NgVeri.py
index 193c51d0..4a221964 100755
--- a/src/maker/NgVeri.py
+++ b/src/maker/NgVeri.py
@@ -229,7 +229,7 @@ class NgVeri(QtWidgets.QWidget):
self.optionsgroupbtn = QtWidgets.QButtonGroup()
self.addverilogbutton = QtWidgets.QPushButton(
- "Run Verilog to NgSpice Converter")
+ "Convert Verilog to Ngspice")
self.addverilogbutton.setToolTip(
"Requires internet connection for converting TL-Verilog models"
)
@@ -240,14 +240,14 @@ class NgVeri(QtWidgets.QWidget):
# self.optionsbox.setLayout(self.optionsgrid)
# self.grid.addWidget(self.creategroup(), 1, 0, 5, 0)
- self.addfilebutton = QtWidgets.QPushButton("Add Other file")
+ self.addfilebutton = QtWidgets.QPushButton("Add dependency files")
self.optionsgroupbtn.addButton(self.addfilebutton)
self.addfilebutton.clicked.connect(self.addfile)
self.optionsgrid.addWidget(self.addfilebutton, 0, 2)
# self.optionsbox.setLayout(self.optionsgrid)
# self.grid.addWidget(self.creategroup(), 1, 0, 5, 0)
- self.addfolderbutton = QtWidgets.QPushButton("Add Folder")
+ self.addfolderbutton = QtWidgets.QPushButton("Add dependency folder")
self.optionsgroupbtn.addButton(self.addfolderbutton)
self.addfolderbutton.clicked.connect(self.addfolder)
self.optionsgrid.addWidget(self.addfolderbutton, 0, 3)
@@ -266,7 +266,7 @@ class NgVeri(QtWidgets.QWidget):
# This function is used to remove models in modlst of Ngspice folder if
# the user wants to remove a model. Note: files do not get removed
def edit_modlst(self, text):
- if text == "Edit modlst":
+ if text == "Remove Verilog Models":
return
index = self.entry_var[1].findText(text)
self.entry_var[1].removeItem(index)
@@ -316,7 +316,7 @@ class NgVeri(QtWidgets.QWidget):
if os.name == 'nt':
init_path = ''
- if text == "Edit lint_off":
+ if text == "Remove lint_off":
return
index = self.entry_var[2].findText(text)
self.entry_var[2].removeItem(index)
@@ -357,7 +357,7 @@ class NgVeri(QtWidgets.QWidget):
file.close()
self.entry_var[3].setText("")
# creating various other groups like terminal, edit modlst, edit lint_off
# and add lint_off
def creategroup(self):
@@ -380,7 +380,7 @@ class NgVeri(QtWidgets.QWidget):
self.count += 1
self.entry_var[self.count] = QtWidgets.QComboBox()
- self.entry_var[self.count].addItem("Edit modlst")
+ self.entry_var[self.count].addItem("Remove Verilog Models")
self.modlst = open(self.digital_home + '/modpath.lst', 'r')
self.data = self.modlst.readlines()
self.modlst.close()
@@ -391,7 +391,7 @@ class NgVeri(QtWidgets.QWidget):
self.trgrid.addWidget(self.entry_var[self.count], 1, 4, 1, 2)
self.count += 1
self.entry_var[self.count] = QtWidgets.QComboBox()
- self.entry_var[self.count].addItem("Edit lint_off")
+ self.entry_var[self.count].addItem("Remove lint_off")
init_path = '../../'
if os.name == 'nt':
@@ -410,7 +410,7 @@ class NgVeri(QtWidgets.QWidget):
self.trgrid.addWidget(self.entry_var[self.count], 3, 4)
self.entry_var[self.count].setMaximumWidth(100)
self.count += 1
- self.entry_var[self.count] = QtWidgets.QPushButton("Add Lint_Off")
+ self.entry_var[self.count] = QtWidgets.QPushButton("Add lint_off")
self.entry_var[self.count].setMaximumWidth(100)
self.trgrid.addWidget(self.entry_var[self.count], 3, 5)
self.entry_var[self.count].clicked.connect(self.add_lint_off)
@@ -357,7 +357,7 @@ class NgVeri(QtWidgets.QWidget):
file.close()
self.entry_var[3].setText("")
- # creating various other groups like terminal, edit modlst, edit lint_off
+ # creating various other groups like terminal, remove modlst, remove lint_off
# and add lint_off
def creategroup(self):